@@ -29,11 +29,8 @@ Usage::
     list_configurations_paginator: ListConfigurationsPaginator = client.get_paginator("list_configurations")
     ```
 """
-from mypy_boto3_discovery.client import (
-    ApplicationDiscoveryServiceClient,
-    ApplicationDiscoveryServiceClient as Client,
-)
-from mypy_boto3_discovery.paginator import (
+from .client import ApplicationDiscoveryServiceClient
+from .paginator import (
     DescribeAgentsPaginator,
     DescribeContinuousExportsPaginator,
     DescribeExportConfigurationsPaginator,
@@ -42,6 +39,8 @@ from mypy_boto3_discovery.paginator import (
     ListConfigurationsPaginator,
 )
 
+Client = ApplicationDiscoveryServiceClient
+
 
 __all__ = (
     "ApplicationDiscoveryServiceClient",
